@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -16,6 +16,7 @@ use strictures 2;
 use namespace::clean;
 
 use constant TICKS => 96;
+use constant OCTAVES => 10;
 
 
 has scale_note => (
@@ -42,7 +43,7 @@ sub _build__scale {
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
     print 'Scale: ', ddc(\@scale) if $self->verbose;
 
-    my @with_octaves = map { my $o = $_; map { $_ . $o } @scale } 0 .. 10;
+    my @with_octaves = map { my $o = $_; map { $_ . $o } @scale } 0 .. OCTAVES;
     print 'With octaves: ', ddc(\@with_octaves) if $self->verbose;
 
     return \@with_octaves;
@@ -79,11 +80,12 @@ has verbose => (
 sub grace_note {
     my ($self, $duration, $pitch, $offset) = @_;
 
-    $offset //= 1;
+    $offset //= 1; # Default one note above
 
     (my $i, $pitch) = $self->_find_pitch($pitch);
     my $grace_note = $self->_scale->[ $i + $offset ];
 
+    # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $y = $MIDI::Simple::Length{yn} * TICKS; # Thirty-second note
     my $z = sprintf '%0.f', $x - $y;
@@ -101,19 +103,20 @@ sub grace_note {
 sub turn {
     my ($self, $duration, $pitch, $offset) = @_;
 
-    my $number = 4;
-    $offset //= 1;
+    my $number = 4; # Number of notes in the ornament
+    $offset //= 1; # Default one note above
 
     (my $i, $pitch) = $self->_find_pitch($pitch);
     my $above = $self->_scale->[ $i + $offset ];
     my $below = $self->_scale->[ $i - $offset ];
 
+    # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $z = sprintf '%0.f', $x / $number;
     print "Durations: $x, $z\n" if $self->verbose;
     $z = 'd' . $z;
 
-    my @turn = ([$z, $above], [$z, $pitch], [$z, $below], [$z, $pitch]);;
+    my @turn = ([$z, $above], [$z, $pitch], [$z, $below], [$z, $pitch]);
     print 'Turn: ', ddc(\@turn) if $self->verbose;
 
     return \@turn;
@@ -123,12 +126,13 @@ sub turn {
 sub trill {
     my ($self, $duration, $pitch, $number, $offset) = @_;
 
-    $number ||= 2;
-    $offset //= 1;
+    $number ||= 2; # Number of notes in the ornament
+    $offset //= 1; # Default one note above
 
     (my $i, $pitch) = $self->_find_pitch($pitch);
     my $alt = $self->_scale->[ $i + $offset ];
 
+    # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $z = sprintf '%0.f', ($x / $number / 2);
     print "Durations: $x, $z\n" if $self->verbose;
@@ -146,12 +150,13 @@ sub trill {
 sub mordent {
     my ($self, $duration, $pitch, $offset) = @_;
 
-    my $number = 4;
-    $offset //= 1;
+    my $number = 4; # Finest division needed
+    $offset //= 1; # Default one note above
 
     (my $i, $pitch) = $self->_find_pitch($pitch);
     my $alt = $self->_scale->[ $i + $offset ];
 
+    # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $y = sprintf '%0.f', $x / $number;
     my $z = sprintf '%0.f', $x - (2 * $y);
@@ -172,7 +177,7 @@ sub slide {
     my ($self, $duration, $from, $to) = @_;
 
     my @scale = get_scale_notes($self->scale_note, 'chromatic');
-    my @with_octaves = map { my $o = $_; map { $_ . $o } @scale } 0 .. 10;
+    my @with_octaves = map { my $o = $_; map { $_ . $o } @scale } 0 .. OCTAVES;
 
     (my $i, $from) = $self->_find_pitch($from, \@with_octaves);
     (my $j, $to) = $self->_find_pitch($to, \@with_octaves);
@@ -187,8 +192,9 @@ sub slide {
         $end = $i;
     }
 
+    # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $y = $end - $start + 1;
+    my $y = $end - $start + 1; # Number of notes in the slide
     my $z = sprintf '%0.f', $x / $y;
     print "Durations: $x, $y, $z\n" if $self->verbose;
     $z = 'd' . $z;
@@ -227,7 +233,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0503
+version 0.0504
 
 =head1 SYNOPSIS
 
@@ -277,7 +283,7 @@ Default: C<C>
 Default: C<chromatic>
 
 For the chromatic scale, enharmonic notes are listed as sharps.  For a
-scale with flats, a diatonic B<scale_name> must be used with a flat
+scale with flats, use a diatonic B<scale_name> with a flat
 B<scale_note>.
 
 Please see L<Music::Scales/SCALES> for a list of valid scale names.
@@ -306,19 +312,19 @@ Create a new C<Music::MelodicDevice::Ornamentation> object.
 
 Default offset: C<1>
 
-"Appoggiatura" means emphasis on the grace note.  "Acciaccatura" means
-emphasis on the main note.  This module doesn't accent notes.  You'll
-have to do that bit.
+I believe that "appoggiatura" means emphasis on the grace note, and
+"acciaccatura" means emphasis on the principle note.  This module
+doesn't accent notes.  You'll have to do that bit.
 
 =head2 turn
 
   $spec = $md->turn($duration, $pitch, $offset);
 
-The note Above, the Principle note (the B<pitch>), the note Below, the
-Principle note again.
+The note C<Above>, the C<Principle> note (the B<pitch>), the note
+C<Below>, followed by the C<Principle> note again.
 
 The default B<offset> is C<1>, but if given as C<-1>, the turn is
-"inverted" and goes: Below, Principle, Above, Principle.
+"inverted" and goes: C<Below>, C<Principle>, C<Above>, C<Principle>.
 
 =head2 trill
 
@@ -342,15 +348,18 @@ note above or below, and the indicated note again."
 An B<offset> of C<1> (the default) returns an upper mordent one pitch
 away.  An B<offset> of C<-1> returns a lower mordent.
 
-So if the B<pitch> is C<D5>, a diatonic upper mordent would be
-C<D5 E5 D5>.  A chromatic lower mordent would be C<D5 C#5 D5>.
+So if the B<pitch> is C<D5>, a diatonic upper mordent, in say C major,
+would be C<D5 E5 D5>.  A chromatic lower mordent would be C<D5 C#5 D5>.
 
 =head2 slide
 
   $spec = $md->slide($duration, $from, $to);
 
-Play each note in the C<chromatic> scale between the B<from> and B<to>
-pitches, for the given B<duration>.
+Return a specification where the notes move (in the C<chromatic>
+scale) between the B<from> and B<to> pitches, for the given
+B<duration>.
+
+This ornament is also known as the "glissando."
 
 =head1 SEE ALSO
 
